.msp-btn-icon[title="Toggle Expanded Viewport"]{display:none}.fullscreen-button{position:absolute;z-index:100;bottom:5px;right:5px;background:rgba(0,0,0,.05);border:0;width:40px;height:40px;border-radius:50%;box-sizing:border-box;transition:-webkit-transform .3s;transition:transform .3s;transition:transform .3s,-webkit-transform .3s;font-size:0;opacity:1;pointer-events:auto;cursor:pointer}.fullscreen-button:hover{-webkit-transform:scale(1.125);transform:scale(1.125)}.fullscreen-button span{background:#fff;width:4px;height:4px;border-top:2.5px solid #111;border-left:2.5px solid #111;position:absolute;outline:1px solid transparent;-webkit-backface-visibility:hidden;-webkit-transform:translateZ(0);transform:translateZ(0);will-change:transform;-webkit-perspective:1000;transition:.3s;transition-delay:.75s}.fullscreen-button span:first-child{top:11px;left:11px}.fullscreen-button span:nth-child(2){top:11px;left:22px;-webkit-transform:rotate(90deg);transform:rotate(90deg)}.fullscreen-button span:nth-child(3){top:22px;left:11px;-webkit-transform:rotate(-90deg);transform:rotate(-90deg)}.fullscreen-button span:nth-child(4){top:22px;left:22px;-webkit-transform:rotate(-180deg);transform:rotate(-180deg)}[fullscreen] .fullscreen-button span:first-child{top:22px;left:22px}[fullscreen] .fullscreen-button span:nth-child(2){top:22px;left:11px}[fullscreen] .fullscreen-button span:nth-child(3){top:11px;left:22px}[fullscreen] .fullscreen-button span:nth-child(4){top:11px;left:11px}[light-mode=dark]{background:#111;color:#fff}[light-mode=dark] .fullscreen-button{background:hsla(0,0%,100%,.05)}[light-mode=dark] .fullscreen-button span{border-top:2.5px solid #fff;border-left:2.5px solid #fff}
/*# sourceMappingURL=main.b4178999.chunk.css.map */